OpenApiRefExt

Trait OpenApiRefExt 

pub trait OpenApiRefExt {
    // Required methods
    fn component_name(&self, component: &str) -> Option<&str>;
    fn resolve_response<'a>(
        &self,
        components: Option<&'a Components>,
    ) -> Option<&'a Response>;

    // Provided methods
    fn schema_name(&self) -> Option<&str> { ... }
    fn response_name(&self) -> Option<&str> { ... }
    fn parameter_name(&self) -> Option<&str> { ... }
    fn example_name(&self) -> Option<&str> { ... }
    fn request_body_name(&self) -> Option<&str> { ... }
    fn header_name(&self) -> Option<&str> { ... }
    fn security_scheme_name(&self) -> Option<&str> { ... }
    fn link_name(&self) -> Option<&str> { ... }
    fn callback_name(&self) -> Option<&str> { ... }
    fn path_item_name(&self) -> Option<&str> { ... }
}
Extension trait for openapi::Ref providing helpers to extract component names.

Required Methods

fn component_name(&self, component: &str) -> Option<&str>

Returns the component name for the given component type if the reference points inside #/components/{component}/....

fn resolve_response<'a>( &self, components: Option<&'a Components>, ) -> Option<&'a Response>

Resolve the referenced response from the supplied OpenAPI components.

Provided Methods

fn schema_name(&self) -> Option<&str>

Returns the referenced schema name if the reference points to #/components/schemas/....

fn response_name(&self) -> Option<&str>

Returns the referenced response name if the reference points to #/components/responses/....

fn parameter_name(&self) -> Option<&str>

Returns the referenced parameter name if the reference points to #/components/parameters/....

fn example_name(&self) -> Option<&str>

Returns the referenced example name if the reference points to #/components/examples/....

fn request_body_name(&self) -> Option<&str>

Returns the referenced request body name if the reference points to #/components/requestBodies/....

fn header_name(&self) -> Option<&str>

Returns the referenced header name if the reference points to #/components/headers/....

fn security_scheme_name(&self) -> Option<&str>

Returns the referenced security scheme name if the reference points to #/components/securitySchemes/....

Returns the referenced link name if the reference points to #/components/links/....

fn callback_name(&self) -> Option<&str>

Returns the referenced callback name if the reference points to #/components/callbacks/....

fn path_item_name(&self) -> Option<&str>

Returns the referenced path item name if the reference points to #/components/pathItems/....

Implementations on Foreign Types

Source

impl OpenApiRefExt for Ref

Source

fn component_name(&self, component: &str) -> Option<&str>

Source

fn resolve_response<'a>( &self, components: Option<&'a Components>, ) -> Option<&'a Response>

Implementors